@@ -1,5 +1,4 @@
-## -----------------------------------------------------------------------------
-library(testthat)
+## ----test00-------------------------------------------------------------------
 library(autoharp)
 library(rlang)
 
